@@ -1,7 +1,7 @@
 package Data::Sah::Resolve;
 
 our $DATE = '2017-04-16'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -19,8 +19,11 @@ sub _resolve {
 
     (my $typemod_pm = "Data/Sah/Type/$type.pm") =~ s!::!/!g;
     eval { require $typemod_pm; 1 };
+    my $err = $@;
     # already a builtin-type, so just return the schema's type name & clause set
-    return [$type, $clsets] unless $@;
+    return [$type, $clsets] unless $err;
+    die "Can't check whether $type is a builtin Sah type: $err"
+        unless $err =~ /\ACan't locate/;
 
     # not a type, try a schema under Sah::Schema
     my $schmod = "Sah::Schema::$type";
@@ -114,7 +117,7 @@ Data::Sah::Resolve - Resolve Sah schema
 
 =head1 VERSION
 
-This document describes version 0.005 of Data::Sah::Resolve (from Perl distribution Data-Sah-Resolve), released on 2017-04-16.
+This document describes version 0.006 of Data::Sah::Resolve (from Perl distribution Data-Sah-Resolve), released on 2017-04-16.
 
 =head1 SYNOPSIS
 
